@@ -21,8 +21,11 @@
 
 #include <sys/param.h>
 
-#if __FreeBSD_version >= 900000
-#error This driver does not support FreeBSD 9.x/-CURRENT!
+#if __FreeBSD_version >= 1000000
+#error This driver does not support FreeBSD 10.x/-CURRENT!
+#endif
+#if __FreeBSD_version >= 900000 && __FreeBSD_version < 900044
+#error This driver requires FreeBSD 9.0 or later!
 #endif
 #if __FreeBSD_version >= 800000 && __FreeBSD_version < 800107
 #error This driver requires FreeBSD 8.0 or later!
