@@ -1752,8 +1752,8 @@ void nvidia_rc_timer(void *data)
 
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, FALSE);
 
-    rm_run_rc_callback(sp, nv);
-    callout_reset(&sc->timer, hz, nvidia_rc_timer, (void *)nv);
+    if (rm_run_rc_callback(sp, nv) == RM_OK)
+        callout_reset(&sc->timer, hz, nvidia_rc_timer, (void *)nv);
 }
 
 int NV_API_CALL nv_start_rc_timer(
