@@ -246,7 +246,7 @@ static void* nvidia_find_bridge(void)
 }
 
 
-int nvidia_sysctl_dev_model(SYSCTL_HANDLER_ARGS)
+int nvidia_sysctl_gpu_model(SYSCTL_HANDLER_ARGS)
 {
     nv_state_t *nv = arg1;
     device_t dev = nv->handle;
@@ -271,7 +271,30 @@ int nvidia_sysctl_dev_model(SYSCTL_HANDLER_ARGS)
     return SYSCTL_OUT(req, model_name, strlen(model_name) + 1);
 }
 
-int nvidia_sysctl_dev_vbios(SYSCTL_HANDLER_ARGS)
+int nvidia_sysctl_gpu_uuid(SYSCTL_HANDLER_ARGS)
+{
+    nv_state_t *nv = arg1;
+    nv_stack_t *sp;
+    NvU8 *uuid;
+    NvU32 uuid_strlen;
+    int ret;
+
+    NV_UMA_ZONE_ALLOC_STACK(sp);
+    if (sp == NULL)
+        return ENOMEM;
+
+    if (rm_get_gpu_uuid(sp, nv, &uuid, &uuid_strlen) != RM_OK)
+        return EIO;
+
+    NV_UMA_ZONE_FREE_STACK(sp);
+
+    ret = SYSCTL_OUT(req, (char *)uuid, uuid_strlen);
+    os_free_mem(uuid);
+
+    return ret;
+}
+
+int nvidia_sysctl_gpu_vbios(SYSCTL_HANDLER_ARGS)
 {
     nv_state_t *nv = arg1;
     nv_stack_t *sp;
@@ -509,10 +532,10 @@ void nv_sysctl_init(nv_state_t *nv)
     oid = SYSCTL_ADD_NODE(&sc->sysctl_ctx,
             SYSCTL_CHILDREN(oid_nvidia),
             OID_AUTO,
-            "cards",
+            "gpus",
             CTLFLAG_RD | CTLFLAG_DYN,
             0,
-            "NVIDIA SYSCTL Cards Node");
+            "NVIDIA SYSCTL GPUs Node");
 
     oid = SYSCTL_ADD_NODE(&sc->sysctl_ctx,
             SYSCTL_CHILDREN(oid),
@@ -520,7 +543,7 @@ void nv_sysctl_init(nv_state_t *nv)
             name,
             CTLFLAG_RD | CTLFLAG_DYN,
             0,
-            "NVIDIA SYSCTL Device Node");
+            "NVIDIA SYSCTL GPU Node");
 
     SYSCTL_ADD_PROC(&sc->sysctl_ctx,
             SYSCTL_CHILDREN(oid),
@@ -528,9 +551,9 @@ void nv_sysctl_init(nv_state_t *nv)
             "model",
             CTLFLAG_RD | CTLFLAG_DYN,
             (void *) nv, 0,
-            nvidia_sysctl_dev_model,
+            nvidia_sysctl_gpu_model,
             "A",
-            "NVIDIA Device Model Name");
+            "NVIDIA GPU Model Name");
 
     SYSCTL_ADD_UINT(&sc->sysctl_ctx,
             SYSCTL_CHILDREN(oid),
@@ -539,7 +562,7 @@ void nv_sysctl_init(nv_state_t *nv)
             CTLFLAG_RD | CTLFLAG_DYN,
             &nv->interrupt_line,
             0,
-            "NVIDIA Device IRQ Number");
+            "NVIDIA GPU IRQ Number");
 
     SYSCTL_ADD_PROC(&sc->sysctl_ctx,
             SYSCTL_CHILDREN(oid),
@@ -547,9 +570,19 @@ void nv_sysctl_init(nv_state_t *nv)
             "vbios",
             CTLFLAG_RD | CTLFLAG_DYN,
             (void *) nv, 0,
-            nvidia_sysctl_dev_vbios,
+            nvidia_sysctl_gpu_vbios,
             "A",
-            "NVIDIA Device VBIOS Version");
+            "NVIDIA GPU VBIOS Version");
+
+    SYSCTL_ADD_PROC(&sc->sysctl_ctx,
+            SYSCTL_CHILDREN(oid),
+            OID_AUTO,
+            "uuid",
+            CTLFLAG_RD | CTLFLAG_DYN,
+            (void *) nv, 0,
+            nvidia_sysctl_gpu_uuid,
+            "A",
+            "NVIDIA GPU UUID");
 
     SYSCTL_ADD_PROC(&sc->sysctl_ctx,
             SYSCTL_CHILDREN(oid),
@@ -559,7 +592,7 @@ void nv_sysctl_init(nv_state_t *nv)
             (void *) sc, 0,
             nvidia_sysctl_bus_type,
             "A",
-            "NVIDIA Device Bus Type");
+            "NVIDIA GPU Bus Type");
 
 
     if (nvidia_pci_find_capability(sc->dev, PCIR_CAP_ID_AGP) != 0) {
